<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class ApropriacaoRecursosFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getApropAgendamento() 
    {
        $sql = "SELECT
                    HORADEC_HORACHAR(APRO.QTHORASAPROPRIADAS)       AS QTHORAS,
                    APRO.NRAPROPAGENDAMENTO,
                    APRO.NRRECURSOSAGENDCONT,
                    APRO.NRPARCNEGRECURSO,
                    RECU.NMPRINCIPALPARC                            AS NMPARCNEGRECURSO,
                    TO_CHAR(APRO.DTAPROPRIACAO, 'DD/MM/YYYY')       AS DTAPROPRIACAO,
                    APRO.IDSTATUSAPROPRIACAO,
                    APRO.QTHORASAPROPRIADAS,
                    APRO.NRPARCINTERLOCUTOR,
                    APRO.NRORG,
                    APRO.IDATIVO,
                    APRO.DTINCLUSAO,
                    APRO.NRORGINCLUSAO,
                    APRO.CDOPERINCLUSAO,
                    APRO.DTULTATU,
                    APRO.NRORGULTATU,
                    APRO.CDOPERULTATU,
                    NVL(ESCALA.HRINICIAL, EQUIPE.HRPRIMEIRAENTRADA) AS HRPRIMEIRAENTRADA,
                    EQUIPE.HRPRIMEIRASAIDA,
                    EQUIPE.HRSEGUNDAENTRADA,
                    NVL(ESCALA.HRFINAL, EQUIPE.HRSEGUNDASAIDA)      AS HRSEGUNDASAIDA,
                    EQUIPE.NRTEMPOTOLERANCIA,
                    AGEND.NRSEQCONTRATO,
                    AGEND.NRAGENDRECURSOCONT,
                    CLI.NRPARCNEGOCIO                               AS NRPARCCLIENTE,
                    CONT.NRCONTRATOFCT
                    || ' - '
                    || CONT.DSREFERENCIACONT                        AS AGENDAMENTO,
                    CLI.NMPRINCIPALPARC                             AS CLIENTE
                FROM
                        FCT_APROPAGENDAMENTO APRO
                    INNER JOIN PARCNEGOCIO                 RECU ON APRO.NRPARCNEGRECURSO = RECU.NRPARCNEGOCIO
                                                AND APRO.NRORG = RECU.NRORG
                    LEFT JOIN FCT_RECURSOSAGENDCONT       EQUIPE ON APRO.NRRECURSOSAGENDCONT = EQUIPE.NRRECURSOSAGENDCONT
                                                            AND APRO.NRORG = EQUIPE.NRORG
                    LEFT JOIN FCT_ESCALARECURSOSAGENDCONT ESCALA ON APRO.NRRECURSOSAGENDCONT = ESCALA.NRRECURSOSAGENDCONT
                                                                    AND APRO.NRORG = ESCALA.NRORG
                                                                    AND DTAPROPRIACAO BETWEEN ESCALA.DTESCALAENTRADA AND ESCALA.DTESCALASAIDA
                    LEFT JOIN FCT_AGENDRECURSOCONT        AGEND ON EQUIPE.NRAGENDRECURSOCONT = AGEND.NRAGENDRECURSOCONT
                                                            AND EQUIPE.NRORG = AGEND.NRORG
                    LEFT JOIN FCT_CONTRATO                CONT ON AGEND.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                                                AND AGEND.NRORG = CONT.NRORG
                    LEFT JOIN PARCNEGOCIO                 CLI ON CONT.NRPARCNEGOCIO = CLI.NRPARCNEGOCIO
                                                AND CONT.NRORG = CLI.NRORG ORDER BY APRO.DTAPROPRIACAO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getRecursosApropAgendamento($parametros) 
    {
        $sql = "SELECT
                    NMRECURSO,
                    CHAVE
                FROM
                    FCT_VIEW_RECURSOS
                WHERE
                        CDTIPO = :CDTIPO
                    AND NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    // continuar a partir daqui passando os parametros 'PROSPECT' e 'CLIENTE'
    public function getParceiroApropAgendamento($parametros) 
    {
        $sql = "SELECT DISTINCT
                    PARCNEGOCIO.NRPARCNEGOCIO,
                    PARCNEGOCIO.NMPRINCIPALPARC,
                    PARCNEGOCIO.NMSECUNDARIPARC,
                    PARCNEGOCIO.NRINSCRICAOPARC,
                    PARCNEGOCIO.CDTIPOPARCPRINCIPAL,
                    PARCNEGOCIO.NRORG,
                    PARCNEGOCIO.CDTIPOINSCRICAO,
                    DECODE(PARCNEGOCIO.IDATIVO, 'S', 'Sim', 'Não') AS IDATIVO,
                    PARCNEGOCIO.CDOPERRESPONSAVEL,
                    OPERADOR.NMOPERADOR                            AS NMOPERRESPONSAVEL,
                    PARCNEGOCIO.CDIDIOM,
                    IDIOMA.NMIDIOMA,
                    PARCNEGOCIO.NRMOEDA,
                    FCT_MOEDA.NMMOEDA
                FROM
                        PARCNEGOCIO
                    INNER JOIN PARCERIA ON PARCNEGOCIO.NRPARCNEGOCIO = PARCERIA.NRPARCNEGOCIO
                                        AND PARCNEGOCIO.NRORG = PARCERIA.NRORG
                    LEFT JOIN OPERADOR ON PARCNEGOCIO.CDOPERRESPONSAVEL = OPERADOR.CDOPERADOR
                                        AND PARCNEGOCIO.NRORG = OPERADOR.NRORG
                    LEFT JOIN IDIOMA ON PARCNEGOCIO.CDIDIOM = IDIOMA.CDIDIOM
                    LEFT JOIN FCT_MOEDA ON PARCNEGOCIO.NRMOEDA = FCT_MOEDA.NRMOEDA
                WHERE
                    PARCERIA.CDTIPOPARCEIRO IN ( :CDTIPOPARCEIRO )";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }    
}