import { Utilities } from '@/util/Utilities';
import {
    Button, Footer, Form, LoadingService, Modal, ModalService, Select,
    Tabs,
    TextInput, Date,
    Frame,
    DialogService,
} from '@zeedhi/common';
import {
    Http, Metadata,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class AgendamentoRecursosController {
    private visibilidadeGridAgendRecursos: boolean = true;

    protected currentRow : any = {};

    private modal!: Modal;

    public get visibilidadeFrameAgendRecursos() {
        return !this.visibilidadeGridAgendRecursos;
    }

    public get tituloFrame() : string {
        return this.currentRow.NRCONTRATOFCT;
    }

    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public async abrirModalAddAgendamentoRecurso() {
        this.modal = await ModalService.createFromJson('agendamentoRecursos/modal/modalAddAgendamentoRecurso', true);
        await this.modal.show();
        Metadata.getInstance<TextInput>('form-modal-agendamento-recursos-add_NRAGENDRECURSOCONT').value = '-1';
    }

    public fecharModalAddAgendRecursos() {
        this.modal.hide();
        this.modal?.destroy();
    }

    public abrirFrameAgendRecursos({ row }: any) {
        this.visibilidadeGridAgendRecursos = false;
        this.currentRow = row;
        this.loadTabsAgendamentoRecursos();
    }
    
    public voltarGridAgendRecursos() {
        this.visibilidadeGridAgendRecursos = true;
        this.ativaTabDescricao();
        this.reloadTabDescricao();
    }

    public reloadTabDescricao() {
        const frame = Metadata.getInstance<Frame>('descricaoAgendamentoRecursos');
        frame.reload();
    }

    public ativaTabDescricao() {
        const setOfTabs = Metadata.getInstance<Tabs>('tabs-agendamento-recursos');
        setOfTabs.activeTab = 0;
    }

    /*
    public async abrirmodalAddPessoa() {
        this.modal = await ModalService.createFromJson('agendamentoRecursos/modal/modalAddPessoa', true);
        this.modal.show();
    }

    public fecharModalAddPessoa() {
        this.modal.hide();
        this.modal?.destroy();
    }

    public setFilterFieldLocalAtendimento() {
        const localAtendimento = Metadata.getInstance<Select>('NMESTRUTURAM');

        localAtendimento.datasource.setFilter({
            NRSEQCONTRATO: null,
            TESTE: 'TESTE',
        });
    }
    */

    public loadTabsAgendamentoRecursos() {
        const setOfTabs = Metadata.getInstance<Tabs>('tabs-agendamento-recursos');
        const footer = Metadata.getInstance<Footer>('footer-agendamento-recurso-descricao');

        if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_descricaoAgendamentoRecursos') {
            footer.isVisible = true;
            this.loadTabDescAgendamentoRecursos();
        } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_equipeTrabalhoAgendamentoRecursos') {
            footer.isVisible = false;
            setTimeout(() => {
                this.loadTabEquipeTrabalhoAgendamentoRecursos();
            }, 1000);
        }
    }

    public loadTabDescAgendamentoRecursos() {
        Metadata.getInstance<TextInput>('form-modal-agendamento-recursos-descricao_NRAGENDRECURSOCONT').value = this.currentRow.NRAGENDRECURSOCONT;
        Metadata.getInstance<Select>('form-modal-agendamento-recursos-descricao_NRSEQCONTRATO').setValue(this.currentRow.NRSEQCONTRATO);
        Metadata.getInstance<TextInput>('form-modal-agendamento-recursos-descricao_NRAGENDRECURSOCONT').value = this.currentRow.NRAGENDRECURSOCONT;
        Metadata.getInstance<Select>('form-modal-agendamento-recursos-descricao_NRESTRUTURAM').value = this.currentRow.NRESTRUTURAM;
        Metadata.getInstance<Date>('form-modal-agendamento-recursos-descricao_DTINIAGENDAMENTO').value = this.currentRow.DTINIAGENDAMENTO;
        Metadata.getInstance<Date>('form-modal-agendamento-recursos-descricao_DTFIMAGENDAMENTO').value = this.currentRow.DTFIMAGENDAMENTO;
    }

    public async loadTabEquipeTrabalhoAgendamentoRecursos() {
        try {
            const grid = Metadata.getInstance<TekGrid>('multiple-levels-grid-item-contrato');
            await grid.datasource.setFilter({
                NRSEQCONTRATO: this.currentRow.NRSEQCONTRATO,
            });
        } catch (error) {
            Utilities.showErrorMessage(error);
        }
    }

    public async openModalEquipeTrabalho() {
        this.modal = await ModalService.createFromJson('agendamentoRecursos/modal/modalAddPessoa', true);
        this.modal.show();
    }

    public fecharModalAddPessoa() {
        this.modal.hide();
        this.modal?.destroy();
    }

    public setFieldsDescCont({ component }: any) {
        const nrseqcontrato = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_NRSEQCONTRATO`).value;
        const nmsecundariparc = Metadata.getInstance<TextInput>(`${component.name.split('_')[0]}_NMSECUNDARIPARC`);
        const dsreferenciacont = Metadata.getInstance<TextInput>(`${component.name.split('_')[0]}_DSREFERENCIACONT`);
        const nrestruturam = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_NRESTRUTURAM`);

        try {
            if (component.datasource.currentRow.NRSEQCONTRATO === nrseqcontrato || nrseqcontrato !== null) {
                nmsecundariparc.value = component.datasource.currentRow.NMSECUNDARIPARC;
                dsreferenciacont.value = component.datasource.currentRow.DSREFERENCIACONT;
            } else {
                nmsecundariparc.value = null;
                dsreferenciacont.value = null;
            }
        
            nrestruturam.datasource.setFilter({
                NRSEQCONTRATO: component.datasource.currentRow.NRSEQCONTRATO,
            });
        } catch (error) {
            Utilities.showErrorMessage(error);
        }
    }

    public saveAgendRecursos({ component }: any) {
        const form = Metadata.getInstance<Form>(`${component.name.split('_')[1]}`);
        const grid = Metadata.getInstance<TekGrid>('grid-agendamento-recursos');

        if (Utilities.validateForm(form)) {
            Http.post('/saveAgendRecursos', {
                NRAGENDRECURSOCONT: Metadata.getInstance<Select>(`${component.name.split('_')[1]}_NRAGENDRECURSOCONT`).value,
                NRSEQCONTRATO: Metadata.getInstance<Select>(`${component.name.split('_')[1]}_NRSEQCONTRATO`).value,
                NRESTRUTURAM: Metadata.getInstance<Select>(`${component.name.split('_')[1]}_NRESTRUTURAM`).value,
                DTINIAGENDAMENTO: Metadata.getInstance<Date>(`${component.name.split('_')[1]}_DTINIAGENDAMENTO`).value,
                DTFIMAGENDAMENTO: Metadata.getInstance<Date>(`${component.name.split('_')[1]}_DTFIMAGENDAMENTO`).value,
            }).then(() => {
                Utilities.showSuccessMessage();
                if (component.name === 'saveButton_form-modal-agendamento-recursos-add') {
                    this.fecharModalAddAgendRecursos();
                }
                grid.datasource.get();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        }
    }

    public dialogDeleteAgendRecursos({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'AgendamentoRecursosController.deleteAgendRecursos');
    }

    public async deleteAgendRecursos() {
        const grid = Metadata.getInstance<TekGrid>('grid-agendamento-recursos');
        LoadingService.show();

        Http.post('/deleteAgendRecursos', {
            NRAGENDRECURSOCONT: grid.selectedRows.map((element: any) => element.NRAGENDRECURSOCONT),
        }).then(() => {
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }
}
